Welcome to PFAS SAT's documentation!
======================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   installation
   Getting_started
   WasteMaterialsProperties
   ProcessModels
   doc_PFAS_SAT
   contributing
   authors
   history
   

Indices and tables
==================
* :ref:`genindex`
* :ref:`search`
